@@ -18,6 +18,7 @@ class Cli():
         make_option('remove', description='Trashes an AppImage, its .desktop file and icons  '),
         make_option('list-installed', description='List integrated apps'),
         make_option('list-updates', description='List available updates'),
+        make_option('list-update-managers', description='List available update managers'),
         make_option('set-update-url', description='Set a custom update url'),
         make_option(FETCH_UPDATES_ARG, description='Fetch updates in the background and sends a desktop notification, used on system startup'),
     ]
@@ -48,8 +49,8 @@ class Cli():
 
         if '--help' in argv:
             table = [[f'--{o.long_name}', o.description] for o in Cli.options]
-            text = f'Usage: flatpak run {APP_ID} [OPTION...]'
-            text += f'\nFor a better user experience, please set `alias gearlever=\'flatpak run {APP_ID}\'` in your .bashrc file'
+            text = f'Usage: gearlever [OPTION...]'
+            text += f'\nFor a better user experience, please set `alias gearlever=\'gearlever\'` in your .bashrc file'
             Cli._print_help_if_requested(argv, table, text)
 
         return -1
@@ -299,6 +300,16 @@ class Cli():
 
         Cli._print_table(table)
 
+    @staticmethod
+    def list_update_managers(argv):
+        models = UpdateManagerChecker.get_models()
+        table = []
+
+        for m in models:
+            table.append([m.label, m.name])
+
+        Cli._print_table(table)
+
     @staticmethod
     def _get_arg_value(argv: list[str], arg_name: str):
         if not arg_name in argv:
